@@ -9,48 +9,10 @@ use File::Find;
 
 use Text::Balanced qw/extract_bracketed extract_multiple/;
 
-our $VERSION = "2.001";
+our $VERSION = "2.002";
 $VERSION = eval $VERSION;
 
-#list of the available transitions
-my @available_transitions = ( qw/
-  Crossfade
-  None
-  PagePeel PageTurn
-  SlideDown SlideLeft SlideRight SlideUp
-  SpinOutIn SpiralOutIn
-  SqueezeDown SqueezeLeft SqueezeRight SqueezeUp
-  WipeBlobs
-  WipeCenterIn WipeCenterOut
-  WipeUp WipeDown WipeLeft WipeRight
-  WipeDownRight WipeUpLeft
-  ZoomOutIn
-/ );
-
-# the "clean" transition set is a basic set useful in all circumstances
-my %clean = (
-  increment => ["WipeRight"],
-  frame => "PageTurn"
-);
-
-# the "sane" transition set sorts the available transitions 
-#  into the two uses as appropriate for a beamer presentation
-my %sane = (
-  increment => [ qw/
-    WipeCenterIn WipeCenterOut
-    WipeUp WipeDown WipeLeft WipeRight
-    WipeDownRight WipeUpLeft
-  / ],
-  frame => [ qw/
-    Crossfade
-    PagePeel PageTurn
-    SlideDown SlideLeft SlideRight SlideUp
-    SpinOutIn SpiralOutIn
-    SqueezeDown SqueezeLeft SqueezeRight SqueezeUp
-    WipeBlobs
-    ZoomOutIn
-  / ]
-);
+use App::makebeamerinfo::Transitions;
 
 #==========================
 # Builder methods
@@ -66,18 +28,13 @@ sub new {
     },
     pages => {}, #holder for page information from nav file
     sections => {}, #holder for section information
-    transitions => undef,  #initialized later
-
-    # holder for making sure that the next random transition
-    #  is not the same as the last
-    last_transition => '',
+    transitions => {}, #holder for all available transition sets
 
     options => {
       # set option to collapse AtBeginSection 
       #  and AtBeginSubsection elements (default true)
       collapse => 1,
-      # set_transition default to clean
-      transition_set => 'clean',
+      transition_set => undef,
     },
   };
 
@@ -85,43 +42,48 @@ sub new {
   $self->{files}{pdf} = abs_path($args->{pdf}) if $args->{pdf};
   $self->{files}{nav} = abs_path($args->{nav}) if $args->{nav};
 
-  # set transition_set if specified and valid
-  my @transition_sets = qw/default clean sane/;
-  if( my $arg_trans = $args->{transition_set} ) {
-    if (grep {$arg_trans eq $_} @transition_sets) {
-      $self->{options}{transition_set} = $arg_trans;
-    } 
-  }
-
   bless $self, $class;
 
-  $self->_init_transitions;
+  $self->_setup_standard_transition_sets;
+
+  $self->transition_set( $args->{transition_set} || 'default' );
+
   $self->_hunt_for_files;
 
   return $self;
   
 }
 
-sub _init_transitions {
+sub _setup_standard_transition_sets {
   my $self = shift;
+  $self->add_transition_set('all', ':all');
+  $self->add_transition_set('default', ':default');
+  $self->add_transition_set('none', ':none');
+  $self->add_transition_set(
+    'turn', 
+    increment => ["WipeRight"],
+    frame => ["PageTurn"],
+  );
 
-  # Initialize Hash of the custom transitions set 
-  #  from array of available transitions
-  my %transitions;
-  foreach my $trans (@available_transitions) {
-    $transitions{'increment'}{$trans} = 0;
-    $transitions{'frame'}{$trans} = 0;
-  }
-
-  # set some base selections for the 'custom' set
-  foreach my $trans (@{ $clean{'increment'} }) {
-    $transitions{'increment'}{$trans} = 1;
-  }
-  foreach my $trans (@{ $sane{'frame'} }) {
-    $transitions{'frame'}{$trans} = 1;
-  }
-
-  $self->{transitions} = \%transitions;
+  # the "most" transition set sorts the available transitions 
+  #  into the two uses as appropriate for a beamer presentation
+  $self->add_transition_set(
+    'most', 
+    increment => [ qw/
+      WipeCenterIn WipeCenterOut
+      WipeUp WipeDown WipeLeft WipeRight
+      WipeDownRight WipeUpLeft
+    / ],
+    frame => [ qw/
+      Crossfade
+      PagePeel PageTurn
+      SlideDown SlideLeft SlideRight SlideUp
+      SpinOutIn SpiralOutIn
+      SqueezeDown SqueezeLeft SqueezeRight SqueezeUp
+      WipeBlobs
+      ZoomOutIn
+    / ],
+  );
 }
 
 sub _hunt_for_files {
@@ -137,6 +99,24 @@ sub _hunt_for_files {
   }
 }
 
+#=========================
+# Transition set helpers
+
+sub add_transition_set {
+  my $self = shift;
+  my $name = $_[0];
+  return $self->{transitions}{$name} = App::makebeamerinfo::Transitions->new( @_ );
+}
+
+sub transition_set {
+  my $self = shift;
+  if ( my $name = shift ) {
+    my $trans = $self->{transitions}{$name} || die "Unknown transition set $name\n";
+    $self->{options}{transition_set} = $trans;
+  }
+  return $self->{options}{transition_set}->name
+}
+
 #==========================
 # common message methods
 
@@ -317,7 +297,7 @@ sub writeInfo {
 
   my $pages = $self->{pages};
   my $sections = $self->{sections};
-  my $options = $self->{options};
+  my $trans = $self->{options}{transition_set};
 
   print $info "PageProps = {\n";
   foreach my $page (sort { $a <=> $b } keys %$pages) {
@@ -336,86 +316,20 @@ sub writeInfo {
     if (
       $pages->{$page}{'type'} eq 'frame' 
       && ! $pages->{$page}{'to_collapse'} 
-      && $options->{'transition_set'} ne 'default'
+      && ! $trans->default_frame
     ) {
-      print $info "\t  \'transition\': " . $self->getFrameTransition() . ",\n";
+      print $info "\t  \'transition\': " . $trans->get_random_element . ",\n";
     }
     print $info "\t},\n";
   }
   print $info "}\n";
-  unless ($options->{'transition_set'} eq 'default') {
+  unless ( $trans->default_increment ) {
     print $info "AvailableTransitions = [";
-    print $info join(", ", $self->getOverallTransitions());
+    print $info join( ", ", $trans->get_selected('increment') );
     print $info "]";
   }
 }
 
-#============================
-# Subs that select certain transitions in certain cases
-
-sub getFrameTransition {
-  my $self = shift;
-
-  my $options = $self->{options};
-
-  my $result;
-  if ($options->{'transition_set'} eq 'custom') { 
-    $result = $self->getRandomElement(
-      $self->get_selected( $self->{transitions}{'frame'} )
-    );
-  } elsif ($options->{'transition_set'} eq 'clean') {
-    $result = $clean{'frame'};
-  } elsif ($options->{'transition_set'} eq 'sane') {
-    $result = $self->getRandomElement( @{ $sane{'frame'} } );
-  }
-  return $result;
-}
-
-sub getOverallTransitions {
-  my $self = shift;
-
-  my $options = $self->{options};
-
-  my @result;
-  if ($options->{'transition_set'} eq 'custom') {
-    @result = $self->get_selected( $self->{transitions}{'increment'} );
-  } elsif ($options->{'transition_set'} eq 'clean') {
-    @result = @{ $clean{'increment'} };
-  } elsif ($options->{'transition_set'} eq 'sane') {
-    @result = @{ $sane{'increment'} };
-  }
-  return @result;
-}
-
-#============================
-# Simple methods to perform actions with data structures
-
-# return the contents of a random element of an array
-sub getRandomElement {
-  my $self = shift;
-  my @input = @_;
-  my $length = @input;
-
-  my $rand = int(rand($length));
-  my $return = $input[$rand];
-
-  # prevent repeated transitions
-  while ($length > 1 && $return eq $self->{last_transition}) {
-    $rand = int(rand($length));
-    $return = $input[$rand];
-  }
-
-  $self->{last_transition} = $return;
-  return $return;
-}
-
-# get the hash keys whose values are true
-sub get_selected {
-  my ($self, $input) = @_;
-  return grep { $input->{$_} } keys %$input;
-}
-
-
 1;
 
 __END__
@@ -459,7 +373,7 @@ L<LaTeX Beamer|http://latex-beamer.sourceforge.net/>
 
 =item *
 
-Need more tests! Specifically, unit tests. This was my first published script, written before I was aware of such thing. The version 2.0 release was requested by user and as such is still lacking a roundly covering test suite. This should be corrected.
+The test suite is improving, but still not excellent coverage. Continuing this is important.
 
 =back
 
@@ -473,7 +387,7 @@ Joel Berger, E<lt>joel.a.berger@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012 by Joel Berger
+Copyright (C) 2012-2013 by Joel Berger
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
